@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.6.0-5
+# Application Name - Health Check V0.6.0-6
 #Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -24,34 +24,44 @@
 # Basic ones
 # import PyQt4 & sys
 print "** Start Imports **"
+print "** Importing qtcore & gui **"
 from PyQt4 import QtCore, QtGui
+print "** Importing sys **"
 import sys
 
 # To allow os.popen ('<<Terminal command>>').read() commands
+print "** Importing os **"
 import os
 # To allow os.popen() to work
+print "** Importing subprocess **"
 import subprocess
+print "** Importing dbus.glib **"
+import dbus.glib
 
 # GPS ones
+print "** Importing Start location**"
 import location
 
-
 # Cell_info - Taken from netmon code. Need to figure out the author so i can give proper thanks!
 # can be found here - http://repository.maemo.org/extras-devel/pool/fremantle/free/source/n/netmon/
+print "** Importing Cellinfo **"
 import gn_cellinfo
-
+print "** Importing Hildon **"
 import hildon
 #import pygtk
 
 #for phone orientation call
-import dbus
-import dbus.glib
-
+#import dbus
+#import dbus.glib
+print "** Importing Threading **"
 from threading import Thread
+print "** Importing Time **"
 import time
+print "** Importing GTK **"
 import gtk
+print "** Initialize Threads **"
 gtk.gdk.threads_init()
-
+print "** Importing Gobject **"
 import gobject
 print "** Finish Imports **"
 
@@ -106,6 +116,7 @@ class Ui_MainWindow(object):
         self.listWidget.setObjectName("listWidget")
         self.listWidget.setFont(font)
         self.listWidget.setAlternatingRowColors(True)
+        self.listWidget.setSizePolicy(QtGui.QSizePolicy.Minimum,QtGui.QSizePolicy.Minimum)
         self.listWidget.setResizeMode(QtGui.QListView.Adjust)
         
         # Setup and draw the button
@@ -207,6 +218,16 @@ class Ui_MainWindow(object):
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
         QtCore.QObject.connect(self.pushButton_reboot, QtCore.SIGNAL('clicked()'), self.reboot_sys)
 
+        self.vibra_led = QtGui.QComboBox(self.tab_4)
+        self.vibra_led.setGeometry(QtCore.QRect(400, 200, 391, 71))
+        self.vibra_led.setObjectName("vibra_led")
+        self.vibra_led.addItem("PatternIncomingCall")
+        self.vibra_led.addItem("PatternIncomingMessage")
+        #self.vibra_led.addItem("PatternPowerKeyPress")
+        #self.vibra_led.addItem("PatternTouchScreen")
+        self.vibra_led.addItem("PatternChatAndEmail")
+        
+        
         self.pushButton_von = QtGui.QPushButton(self.tab_4)
         self.pushButton_von.setGeometry(QtCore.QRect(10, 200, 391, 71))
         self.pushButton_von.setObjectName("pushButton_von")
@@ -214,6 +235,27 @@ class Ui_MainWindow(object):
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
         QtCore.QObject.connect(self.pushButton_von, QtCore.SIGNAL('clicked()'), self.vibrateon)
 
+        self.combo_led = QtGui.QComboBox(self.tab_4)
+        self.combo_led.setGeometry(QtCore.QRect(400, 120, 391, 71))
+        self.combo_led.setObjectName("combo_led")
+        self.combo_led.addItem("PatternError")
+        #self.combo_led.addItem("PatternDeviceOn")
+        #self.combo_led.addItem("PatternDeviceSoftOff")
+        self.combo_led.addItem("PatternPowerOn")
+        self.combo_led.addItem("PatternPowerOff")
+        self.combo_led.addItem("PatternCommunicationCall")
+        #self.combo_led.addItem("PatternCommunicationIM")
+        self.combo_led.addItem("PatternCommunicationSMS")
+        #self.combo_led.addItem("PatternCommunicationEmail")
+        #self.combo_led.addItem("PatternCommonNotification")
+        #self.combo_led.addItem("PatternBatteryCharging")
+        #self.combo_led.addItem("PatternBatteryFull")
+
+        
+        # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
+        #QtCore.QObject.connect(self.pushButton_von, QtCore.SIGNAL('clicked()'), self.vibrateon)
+        
+
         self.pushButton_led = QtGui.QPushButton(self.tab_4)
         self.pushButton_led.setGeometry(QtCore.QRect(10, 120, 391, 71))
         self.pushButton_led.setObjectName("pushButton_led")
@@ -221,6 +263,16 @@ class Ui_MainWindow(object):
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
         QtCore.QObject.connect(self.pushButton_led, QtCore.SIGNAL('clicked()'), self.updateLED)
 
+        self.sound_lst = QtGui.QComboBox(self.tab_4)
+        self.sound_lst.setGeometry(QtCore.QRect(400, 40, 391, 71))
+        self.sound_lst.setObjectName("sound_lst")
+        for f in os.listdir("/usr/share/sounds/"):
+            #print f[-3:]
+            if f[-3:] == "wav":
+                self.sound_lst.addItem(f)
+        #self.sound_lst.addItem("PatternIncomingCall")
+
+
         self.pushButton_snd1 = QtGui.QPushButton(self.tab_4)
         self.pushButton_snd1.setGeometry(QtCore.QRect(10, 40, 391, 71))
         self.pushButton_snd1.setObjectName("pushButton_snd1")
@@ -239,7 +291,7 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_5)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText (" Health Check V 0.6.0-5 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
+        self.textBrowser.setText (" Health Check V 0.6.0-6 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
@@ -343,14 +395,18 @@ class Ui_MainWindow(object):
         bus = dbus.SessionBus()
         proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
         interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
-        interface.Notify('HealthCheck', 0, 'general_refresh', 'Sound Test', 'Stereo then Mono Test', [], {}, 3000)
-        print "** Starting STero Test **"
-        b = None
-        b = os.popen('pacat --channels=2 /usr/share/sounds/ui-wake_up_tune.wav')
+        interface.Notify('HealthCheck', 0, 'general_refresh', 'Sound Test', 'Testing Stero/Mono Sound', [], {}, 3000)
+        print "** Starting Stereo Test **"
+        bb = 'pacat --channels=2 ' + '/usr/share/sounds/' + self.sound_lst.currentText()
+        bb = str(bb)
+        print bb
+        b = os.popen(bb)
         b.close ()
         print "** Starting Mono Test**"
-        b = None
-        b = os.popen('pacat --channels=1 /usr/share/sounds/ui-wake_up_tune.wav')
+        bb = 'pacat --channels=1 ' + '/usr/share/sounds/' + self.sound_lst.currentText()
+        bb = str(bb)
+        print bb
+        b = os.popen(bb)
         b.close ()
               
 # Funtion - update the front camera image
@@ -484,6 +540,8 @@ class Ui_MainWindow(object):
         ge = ge.strip()
     
         self.listWidget.addItem("FM Trans Strength \t\t" + ge.strip())
+
+ 
         
     def updatenetname(self):
         print " ** Getting host name**"
@@ -491,11 +549,32 @@ class Ui_MainWindow(object):
         ga = ga.strip()
         self.listWidget2.addItem("Device Hostname \t" + ga.strip())
 
+        #print " ** Getting IMEI**"
+        #bb = 'run-standalone.sh dbus-send --system --print-reply --type=method_call --dest=com.nokia.phone.SIM /com/nokia/phone/SIM/security Phone.Sim.Security.get_imei'
+        b = os.popen('run-standalone.sh dbus-send --system --print-reply --type=method_call --dest=com.nokia.phone.SIM /com/nokia/phone/SIM/security Phone.Sim.Security.get_imei').read()
+        
+        b = str(b)
+        b = b.strip()
+        #b = str(b)[:-15]
+        b = str(b)[-27:]
+        b = b.strip()
+        b = str(b)[:-12]
+        print b + "*"
+        self.listWidget2.addItem("Device IMEI \t\t" + b.strip())
+        #b.close()
+
+        #b = os.popen('run-standalone.sh dbus-send --system --type=method_call --print-reply --dest=com.nokia.phone.net /com/nokia/phone/net Phone.Net.get_registration_status').read()
+        #b=str(b)
+        #self.listWidget.addItem("Phone Registration \t" + b.strip())
+        
+        
     def updateUptime(self):
         print " ** Getting system uptime**"
         # This one reads fremantle version number (Firmware)
         ge = os.popen('uptime|cut -d" " -f4-|cut -d"," -f-1').read()
         self.listWidget.addItem("System Uptime \t\t" + ge.strip())
+
+
      
 
 # Funtion - update battery information
@@ -557,74 +636,46 @@ class Ui_MainWindow(object):
         # the co-ords need to be pulled out and split for easy reading
         # Close down the co-ord file once used (Only displaying static info, not updating yet)
         
-        bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'PatternTouchscreen\'"
+        bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'" + self.vibra_led.currentText() + "\'"
+        bb = str(bb)
         b = os.popen(bb)
         b.close()
-        bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'PatternTouchscreen\'"
+        bb = 'run-standalone.sh sleep 5'
         b = os.popen(bb)
         b.close()
-        bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'PatternTouchscreen\'"
-        b = os.popen(bb)
-        b.close()
-        bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'PatternTouchscreen\'"
-        b = os.popen(bb)
-        b.close()
-        bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'PatternTouchscreen\'"
-        b = os.popen(bb)
-        b.close()
-        bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'PatternTouchscreen\'"
-        b = os.popen(bb)
-        b.close()
-        bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'PatternTouchscreen\'"
-        b = os.popen(bb)
-        b.close()
-        bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'PatternTouchscreen\'"
-        b = os.popen(bb)
-        b.close()
-        bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'PatternTouchscreen\'"
-        b = os.popen(bb)
-        b.close()
-        bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'PatternTouchscreen\'"
-        b = os.popen(bb)
-        b.close()
-        
-        b.close()
-        bb= 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_deactivate string:' + "\'PatternIncomingCall\'"
+        bb= 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_deactivate string:' + "\'" + self.vibra_led.currentText() + "\'"
+        bb = str(bb)
         b = os.popen(bb)
         b.close()
         print " ** finished vibrations**"
         
     def updateLED(self):
         #print " ** importing dbus.glib**"
-        #import dbus.glib
-        #print " ** Starting LED Patterns**"
+        print " ** Starting LED Patterns**"
         bus = dbus.SessionBus()
         proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
         interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
-        interface.Notify('HealthCheck', 0, 'general_refresh', 'LED TEST', 'Testing Power on, then SMS LED Patterns ', [], {}, 3000)
+        interface.Notify('HealthCheck', 0, 'general_refresh', 'LED TEST', 'Starting LED Test', [], {}, 3000)
+        
 
-        bb = 'run-standalone.sh dbus-send --system --type=method_call --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_led_pattern_activate string:' + "\'PatternPowerOn\'"
+        bb = 'run-standalone.sh dbus-send --system --type=method_call --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_led_pattern_activate string:' + "\'" + self.combo_led.currentText() + "\'"
+        bb = str(bb)
         b = os.popen(bb)
         b.close()
-        bb = 'run-standalone.sh sleep 1'
+        bb = 'run-standalone.sh sleep 4'
         b = os.popen(bb)
         b.close()
-        bb = 'run-standalone.sh dbus-send --system --type=method_call --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_led_pattern_deactivate string:' + "\'PatternPowerOn\'"
+        bb = 'run-standalone.sh dbus-send --system --type=method_call --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_led_pattern_deactivate string:' + "\'" + self.combo_led.currentText() + "\'"
+        bb = str(bb)
         b = os.popen(bb)
         b.close()
-
-        bb = 'run-standalone.sh dbus-send --system --type=method_call --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_led_pattern_activate string:' + "\'PatternCommunicationSMS\'"
-        b = os.popen(bb)
-        b.close()
-        bb = 'run-standalone.sh sleep 1'
-        b = os.popen(bb)
-        b.close()
-        bb = 'run-standalone.sh dbus-send --system --type=method_call --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_led_pattern_deactivate string:' + "\'PatternCommunicationSMS\'"
-        b = os.popen(bb)
+ 
         b.close()
         print " ** Finished LED Patterns **"
-
-      
+        bus = dbus.SessionBus()
+        proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
+        interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
+        interface.Notify('HealthCheck', 0, 'general_refresh', 'LED TEST', 'Completed LED Test', [], {}, 3000)
 
 
 # Funtion - update rootfs, currently shows free MB and used %.
@@ -727,7 +778,7 @@ class Ui_MainWindow(object):
         
     # This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.6.0-5", None, QtGui.QApplication.UnicodeUTF8))
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.6.0-6", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Camera", None, QtGui.QApplication.UnicodeUTF8))
